==> polars-0.18.6-cp38-abi3-macosx_10_7_x86_64.whl: polars/functions/__init__.py <==
from polars.functions.as_datatype import (
    concat_list,
    concat_str,
    duration,
    format,
    struct,
)
from polars.functions.as_datatype import date_ as date
from polars.functions.as_datatype import datetime_ as datetime
from polars.functions.as_datatype import time_ as time
from polars.functions.eager import align_frames, concat
from polars.functions.lazy import (
    all,
    any,
    apply,
    approx_unique,
    arg_sort_by,
    arg_where,
    avg,
    coalesce,
    col,
    collect_all,
    corr,
    count,
    cov,
    cumfold,
    cumreduce,
    cumsum,
    element,
    exclude,
    first,
    fold,
    from_epoch,
    groups,
    head,
    implode,
    last,
    lit,
    map,
    max,
    mean,
    median,
    min,
    n_unique,
    quantile,
    reduce,
    rolling_corr,
    rolling_cov,
    select,
    sql_expr,
    std,
    sum,
    tail,
    var,
)
from polars.functions.range import arange, date_range, int_range, int_ranges, time_range
from polars.functions.repeat import ones, repeat, zeros
from polars.functions.whenthen import when

__all__ = [
    # polars.functions.eager
    "align_frames",
    "approx_unique",
    "arg_where",
    "concat",
    "date_range",
    "element",
    "ones",
    "repeat",
    "time_range",
    "zeros",
    # polars.functions.lazy
    "all",
    "any",
    "apply",
    "arange",
    "arg_sort_by",
    "avg",
    "coalesce",
    "col",
    "collect_all",
    "concat_list",
    "concat_str",
    "corr",
    "count",
    "cov",
    "cumfold",
    "cumreduce",
    "cumsum",
    "date",  # named date_, see import above
    "datetime",  # named datetime_, see import above
    "duration",
    "exclude",
    "first",
    "fold",
    "format",
    "from_epoch",
    "groups",
    "head",
    "implode",
    "int_range",
    "int_ranges",
    "last",
    "lit",
    "map",
    "max",
    "mean",
    "median",
    "min",
    "n_unique",
    "quantile",
    "reduce",
    "rolling_corr",
    "rolling_cov",
    "select",
    "std",
    "struct",
    "sum",
    "tail",
    "time",
    "var",
    # polars.functions.whenthen
    "when",
    "sql_expr",
]

==> polars-0.20.4-cp38-abi3-macosx_10_12_x86_64.whl: polars/functions/__init__.py <==
from polars.functions.aggregation import (
    all,
    all_horizontal,
    any,
    any_horizontal,
    cum_sum,
    cum_sum_horizontal,
    cumsum,
    cumsum_horizontal,
    max,
    max_horizontal,
    min,
    min_horizontal,
    sum,
    sum_horizontal,
)
from polars.functions.as_datatype import (
    concat_list,
    concat_str,
    duration,
    format,
    struct,
)
from polars.functions.as_datatype import date_ as date
from polars.functions.as_datatype import datetime_ as datetime
from polars.functions.as_datatype import time_ as time
from polars.functions.col import col
from polars.functions.eager import align_frames, concat
from polars.functions.lazy import (
    apply,
    approx_n_unique,
    arctan2,
    arctan2d,
    arg_sort_by,
    arg_where,
    coalesce,
    collect_all,
    collect_all_async,
    corr,
    count,
    cov,
    cum_count,
    cum_fold,
    cum_reduce,
    cumfold,
    cumreduce,
    element,
    exclude,
    first,
    fold,
    from_epoch,
    groups,
    head,
    implode,
    last,
    map,
    map_batches,
    map_groups,
    mean,
    median,
    n_unique,
    quantile,
    reduce,
    rolling_corr,
    rolling_cov,
    select,
    sql_expr,
    std,
    tail,
    var,
)
from polars.functions.lit import lit
from polars.functions.random import set_random_seed
from polars.functions.range import (
    arange,
    date_range,
    date_ranges,
    datetime_range,
    datetime_ranges,
    int_range,
    int_ranges,
    time_range,
    time_ranges,
)
from polars.functions.repeat import ones, repeat, zeros
from polars.functions.whenthen import when

__all__ = [
    # polars.functions.aggregation
    "all",
    "any",
    "cum_sum",
    "cumsum",
    "max",
    "min",
    "sum",
    "all_horizontal",
    "any_horizontal",
    "cum_sum_horizontal",
    "cumsum_horizontal",
    "max_horizontal",
    "min_horizontal",
    "sum_horizontal",
    # polars.functions.eager
    "align_frames",
    "approx_n_unique",
    "arg_where",
    "concat",
    "date_range",
    "date_ranges",
    "datetime_range",
    "datetime_ranges",
    "element",
    "ones",
    "repeat",
    "time_range",
    "time_ranges",
    "zeros",
    # polars.functions.lazy
    "apply",
    "arange",
    "arctan2",
    "arctan2d",
    "arg_sort_by",
    "coalesce",
    "col",
    "collect_all",
    "collect_all_async",
    "concat_list",
    "concat_str",
    "corr",
    "count",
    "cov",
    "cum_count",
    "cum_fold",
    "cum_reduce",
    "cumfold",
    "cumreduce",
    "date",  # named date_, see import above
    "datetime",  # named datetime_, see import above
    "duration",
    "exclude",
    "first",
    "fold",
    "format",
    "from_epoch",
    "groups",
    "head",
    "implode",
    "int_range",
    "int_ranges",
    "last",
    "lit",
    "map",
    "map_batches",
    "map_groups",
    "mean",
    "median",
    "n_unique",
    "quantile",
    "reduce",
    "rolling_corr",
    "rolling_cov",
    "select",
    "set_random_seed",
    "std",
    "struct",
    "tail",
    "time",
    "var",
    # polars.functions.whenthen
    "when",
    "sql_expr",
]
